@@ -12,7 +12,7 @@ except ImportError:
 
 
 LOGGING_LEVELS = [logging.getLevelName(level).lower() for level in range(0, 51, 10)]
-VERSION = "2021.3.16"  # Avoid importing optimade-client package
+VERSION = "2021.3.29"  # Avoid importing optimade-client package
 
 
 def main(args: list = None):
@@ -80,17 +80,14 @@ def main(args: list = None):
 
     argv = [notebook]
 
-    if sys.version_info.minor <= 6:
-        # Python 3.6 and below (officially only supports Python 3.6+)
-        argv.append(f'--Voila.config_file_paths=["{config_path}"]')
-    else:
-        argv.append(f"--Voila.config_file_paths={config_path}")
+    argv.append(f"--Voila.config_file_paths={config_path}")
 
     if debug:
         if log_level not in ("debug", "info"):
             print("[OPTIMADE-Client] Overwriting requested log-level to: 'debug'")
         os.environ["OPTIMADE_CLIENT_DEBUG"] = "True"
         argv.append("--debug")
+        argv.append("--show_tracebacks=True")
     else:
         os.environ.pop("OPTIMADE_CLIENT_DEBUG", None)
 
